@@ -1,2 +1,2 @@
-from .AqSpeciation import AqEquil, load, compare, Speciation
+from .AqSpeciation import Thermodata, AqEquil, load, compare, Speciation
 from .MassTransfer import Mass_Transfer, react, Reactant, Gas, Prepare_Reaction
\ No newline at end of file
